@@ -84,7 +84,7 @@ appointments.post(
       body: { facilityId, schedule: scheduleData, ...appointmentData },
       settings,
     } = req;
-    const { Appointment } = models;
+    const { Appointment, PatientFacility } = models;
     const result = await db.transaction(async () => {
       const appointment = scheduleData
         ? (
@@ -96,6 +96,10 @@ appointments.post(
           ).firstAppointment
         : await Appointment.create(appointmentData);
 
+      await PatientFacility.findOrCreate({
+        where: { patientId: appointment.patientId, facilityId },
+      });
+
       const { email } = appointmentData;
       if (email) {
         await sendAppointmentReminder({
@@ -188,7 +192,7 @@ appointments.put(
   }),
 );
 
-const isStringOrArray = (obj) => typeof obj === 'string' || Array.isArray(obj);
+const isStringOrArray = obj => typeof obj === 'string' || Array.isArray(obj);
 
 const CONTAINS_SEARCHABLE_FIELDS = [
   'patient.first_name',
@@ -229,7 +233,7 @@ const sortKeys = {
   bookingArea: Sequelize.col('location.locationGroup.name'),
 };
 
-const buildPatientNameOrIdQuery = (patientNameOrId) => {
+const buildPatientNameOrIdQuery = patientNameOrId => {
   if (!patientNameOrId) return null;
 
   const ilikeClause = {
@@ -352,11 +356,11 @@ appointments.post(
     req.checkPermission('create', 'Appointment');
 
     const { models, body } = req;
-    const { startTime, endTime, locationId } = body;
-    const { Appointment } = models;
+    const { startTime, endTime, locationId, patientId } = body;
+    const { Appointment, PatientFacility, Location } = models;
 
     try {
-      const result = await Appointment.sequelize.transaction(async (transaction) => {
+      const result = await Appointment.sequelize.transaction(async transaction => {
         const [timeQueryWhereClause, timeQueryBindParams] = buildTimeQuery(startTime, endTime);
         const conflictCount = await Appointment.count({
           where: {
@@ -374,6 +378,14 @@ appointments.post(
 
         if (conflictCount > 0) throw new ResourceConflictError();
 
+        const location = await Location.findByPk(locationId, { transaction });
+        if (!location) throw new NotFoundError('Location not found');
+
+        await PatientFacility.findOrCreate({
+          where: { patientId, facilityId: location.facilityId },
+          transaction,
+        });
+
         return await Appointment.create(body, { transaction });
       });
 
@@ -396,7 +408,7 @@ appointments.put(
     const { Appointment } = models;
 
     try {
-      const result = await Appointment.sequelize.transaction(async (transaction) => {
+      const result = await Appointment.sequelize.transaction(async transaction => {
         const existingBooking = await Appointment.findByPk(id, { transaction });
 
         if (!existingBooking) {
